<?php

namespace App\Controller;

use App\Form\SecuritySignInForm;
use Exception;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Authentication\AuthenticationUtils;

/**
 * Controller about security (login / logout)
 *
 * @package App\Controller
 */
class SecurityController extends AbstractController {
    /**
     * Show login form
     *
     * @param AuthenticationUtils $authenticationUtils Helper for authentication information
     *
     * @return Response Page response
     *
     * @Route("/sign-in")
     */
    public function sign_in (AuthenticationUtils $authenticationUtils): Response {
        $form = $this->createForm(
            SecuritySignInForm::class,
            [
                'email' => $authenticationUtils->getLastUsername(),
            ]
        );

        return $this->render(
            'security/sign-in.html.twig',
            [
                'error' => $authenticationUtils->getLastAuthenticationError(),
                'form'  => $form->createView(),
            ]
        );
    }

    /**
     * *Perform* logout
     *
     * @throws Exception When firewall failed and this method is *really* called
     *
     * @Route("/sign-out")
     */
    public function sign_out () {
        throw new Exception('This method can be blank - it will be intercepted by the logout key on your firewall');
    }

    /**
     * Show inscription form
     *
     * @Route("/sign-up")
     */
    public function sign_up () {
    }
}
